/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qstandarditemmodel.sip"
#include <qstandarditemmodel.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"

#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 26 "sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 103 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qstandarditemmodel.sip"
#include <qstandarditemmodel.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 275 "sip/QtCore/qpycore_qhash.sip"
#include <qhash.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 26 "sip/QtCore/qmimedata.sip"
#include <qmimedata.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 54 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 36 "sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 57 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 60 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 63 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 66 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 146 "sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 69 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 72 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 75 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 78 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 111 "sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 81 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 26 "sip/QtCore/qdatastream.sip"
#include <qdatastream.h>
#line 84 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 87 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 76 "sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 90 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 111 "sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 93 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 442 "sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 96 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 26 "sip/QtCore/qsize.sip"
#include <qsize.h>
#line 99 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 104 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 107 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 110 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 113 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 116 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 119 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 122 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 26 "sip/QtCore/qthread.sip"
#include <qthread.h>
#line 125 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 128 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 26 "sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 131 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 26 "sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 134 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 137 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStandardItemModel.cpp"


class sipQStandardItemModel : public  ::QStandardItemModel
{
public:
    sipQStandardItemModel( ::QObject*);
    sipQStandardItemModel(int,int, ::QObject*);
    virtual ~sipQStandardItemModel();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event( ::QEvent*) SIP_OVERRIDE;
     ::QModelIndex index(int,int,const  ::QModelIndex&) const SIP_OVERRIDE;
     ::QModelIndex parent(const  ::QModelIndex&) const SIP_OVERRIDE;
     ::QModelIndex sibling(int,int,const  ::QModelIndex&) const SIP_OVERRIDE;
    int rowCount(const  ::QModelIndex&) const SIP_OVERRIDE;
    int columnCount(const  ::QModelIndex&) const SIP_OVERRIDE;
    bool hasChildren(const  ::QModelIndex&) const SIP_OVERRIDE;
     ::QVariant data(const  ::QModelIndex&,int) const SIP_OVERRIDE;
    bool setData(const  ::QModelIndex&,const  ::QVariant&,int) SIP_OVERRIDE;
     ::QVariant headerData(int, ::Qt::Orientation,int) const SIP_OVERRIDE;
    bool setHeaderData(int, ::Qt::Orientation,const  ::QVariant&,int) SIP_OVERRIDE;
    QMap<int, ::QVariant> itemData(const  ::QModelIndex&) const SIP_OVERRIDE;
    bool setItemData(const  ::QModelIndex&,const QMap<int, ::QVariant>&) SIP_OVERRIDE;
     ::QStringList mimeTypes() const SIP_OVERRIDE;
     ::QMimeData* mimeData(const  ::QModelIndexList&) const SIP_OVERRIDE;
    bool dropMimeData(const  ::QMimeData*, ::Qt::DropAction,int,int,const  ::QModelIndex&) SIP_OVERRIDE;
     ::Qt::DropActions supportedDropActions() const SIP_OVERRIDE;
    bool insertRows(int,int,const  ::QModelIndex&) SIP_OVERRIDE;
    bool insertColumns(int,int,const  ::QModelIndex&) SIP_OVERRIDE;
    bool removeRows(int,int,const  ::QModelIndex&) SIP_OVERRIDE;
    bool removeColumns(int,int,const  ::QModelIndex&) SIP_OVERRIDE;
    void fetchMore(const  ::QModelIndex&) SIP_OVERRIDE;
    bool canFetchMore(const  ::QModelIndex&) const SIP_OVERRIDE;
     ::Qt::ItemFlags flags(const  ::QModelIndex&) const SIP_OVERRIDE;
    void sort(int, ::Qt::SortOrder) SIP_OVERRIDE;
     ::QModelIndex buddy(const  ::QModelIndex&) const SIP_OVERRIDE;
     ::QModelIndexList match(const  ::QModelIndex&,int,const  ::QVariant&,int, ::Qt::MatchFlags) const SIP_OVERRIDE;
     ::QSize span(const  ::QModelIndex&) const SIP_OVERRIDE;
    bool submit() SIP_OVERRIDE;
    void revert() SIP_OVERRIDE;
     ::Qt::DropActions supportedDragActions() const SIP_OVERRIDE;
    QHash<int, ::QByteArray> roleNames() const SIP_OVERRIDE;
    bool canDropMimeData(const  ::QMimeData*, ::Qt::DropAction,int,int,const  ::QModelIndex&) const SIP_OVERRIDE;
    bool moveRows(const  ::QModelIndex&,int,int,const  ::QModelIndex&,int) SIP_OVERRIDE;
    bool moveColumns(const  ::QModelIndex&,int,int,const  ::QModelIndex&,int) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQStandardItemModel(const sipQStandardItemModel &);
    sipQStandardItemModel &operator = (const sipQStandardItemModel &);

    char sipPyMethods[41];
};

sipQStandardItemModel::sipQStandardItemModel( ::QObject*a0):  ::QStandardItemModel(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQStandardItemModel::sipQStandardItemModel(int a0,int a1, ::QObject*a2):  ::QStandardItemModel(a0,a1,a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQStandardItemModel::~sipQStandardItemModel()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQStandardItemModel::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtGui_qt_metaobject(sipPySelf,sipType_QStandardItemModel);

    return  ::QStandardItemModel::metaObject();
}

int sipQStandardItemModel::qt_metacall(QMetaObject::Call _c,int _id,void **_a)
{
    _id =  ::QStandardItemModel::qt_metacall(_c,_id,_a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtGui_qt_metacall(sipPySelf,sipType_QStandardItemModel,_c,_id,_a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQStandardItemModel::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtGui_qt_metacast(sipPySelf, sipType_QStandardItemModel, _clname, &sipCpp) ? sipCpp :  ::QStandardItemModel::qt_metacast(_clname));
}

void sipQStandardItemModel::disconnectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,SIP_NULLPTR,sipName_disconnectNotify);

    if (!sipMeth)
    {
         ::QStandardItemModel::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtGui_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtGui_0(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStandardItemModel::connectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,SIP_NULLPTR,sipName_connectNotify);

    if (!sipMeth)
    {
         ::QStandardItemModel::connectNotify(a0);
        return;
    }

    extern void sipVH_QtGui_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtGui_0(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStandardItemModel::customEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[2],sipPySelf,SIP_NULLPTR,sipName_customEvent);

    if (!sipMeth)
    {
         ::QStandardItemModel::customEvent(a0);
        return;
    }

    extern void sipVH_QtGui_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_QtGui_1(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStandardItemModel::childEvent( ::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[3],sipPySelf,SIP_NULLPTR,sipName_childEvent);

    if (!sipMeth)
    {
         ::QStandardItemModel::childEvent(a0);
        return;
    }

    extern void sipVH_QtGui_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QChildEvent*);

    sipVH_QtGui_2(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStandardItemModel::timerEvent( ::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[4],sipPySelf,SIP_NULLPTR,sipName_timerEvent);

    if (!sipMeth)
    {
         ::QStandardItemModel::timerEvent(a0);
        return;
    }

    extern void sipVH_QtGui_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTimerEvent*);

    sipVH_QtGui_3(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQStandardItemModel::eventFilter( ::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[5],sipPySelf,SIP_NULLPTR,sipName_eventFilter);

    if (!sipMeth)
        return  ::QStandardItemModel::eventFilter(a0,a1);

    extern bool sipVH_QtGui_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*, ::QEvent*);

    return sipVH_QtGui_4(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQStandardItemModel::event( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[6],sipPySelf,SIP_NULLPTR,sipName_event);

    if (!sipMeth)
        return  ::QStandardItemModel::event(a0);

    extern bool sipVH_QtGui_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    return sipVH_QtGui_5(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::QModelIndex sipQStandardItemModel::index(int a0,int a1,const  ::QModelIndex& a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[7]),sipPySelf,SIP_NULLPTR,sipName_index);

    if (!sipMeth)
        return  ::QStandardItemModel::index(a0,a1,a2);

    extern  ::QModelIndex sipVH_QtGui_97(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int,int,const  ::QModelIndex&);

    return sipVH_QtGui_97(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

 ::QModelIndex sipQStandardItemModel::parent(const  ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[8]),sipPySelf,SIP_NULLPTR,sipName_parent);

    if (!sipMeth)
        return  ::QStandardItemModel::parent(a0);

    extern  ::QModelIndex sipVH_QtGui_82(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QModelIndex&);

    return sipVH_QtGui_82(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::QModelIndex sipQStandardItemModel::sibling(int a0,int a1,const  ::QModelIndex& a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[9]),sipPySelf,SIP_NULLPTR,sipName_sibling);

    if (!sipMeth)
        return  ::QStandardItemModel::sibling(a0,a1,a2);

    extern  ::QModelIndex sipVH_QtGui_97(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int,int,const  ::QModelIndex&);

    return sipVH_QtGui_97(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

int sipQStandardItemModel::rowCount(const  ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[10]),sipPySelf,SIP_NULLPTR,sipName_rowCount);

    if (!sipMeth)
        return  ::QStandardItemModel::rowCount(a0);

    extern int sipVH_QtGui_96(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QModelIndex&);

    return sipVH_QtGui_96(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQStandardItemModel::columnCount(const  ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[11]),sipPySelf,SIP_NULLPTR,sipName_columnCount);

    if (!sipMeth)
        return  ::QStandardItemModel::columnCount(a0);

    extern int sipVH_QtGui_96(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QModelIndex&);

    return sipVH_QtGui_96(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQStandardItemModel::hasChildren(const  ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[12]),sipPySelf,SIP_NULLPTR,sipName_hasChildren);

    if (!sipMeth)
        return  ::QStandardItemModel::hasChildren(a0);

    extern bool sipVH_QtGui_85(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QModelIndex&);

    return sipVH_QtGui_85(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::QVariant sipQStandardItemModel::data(const  ::QModelIndex& a0,int a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[13]),sipPySelf,SIP_NULLPTR,sipName_data);

    if (!sipMeth)
        return  ::QStandardItemModel::data(a0,a1);

    extern  ::QVariant sipVH_QtGui_95(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QModelIndex&,int);

    return sipVH_QtGui_95(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQStandardItemModel::setData(const  ::QModelIndex& a0,const  ::QVariant& a1,int a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[14],sipPySelf,SIP_NULLPTR,sipName_setData);

    if (!sipMeth)
        return  ::QStandardItemModel::setData(a0,a1,a2);

    extern bool sipVH_QtGui_94(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QModelIndex&,const  ::QVariant&,int);

    return sipVH_QtGui_94(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

 ::QVariant sipQStandardItemModel::headerData(int a0, ::Qt::Orientation a1,int a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[15]),sipPySelf,SIP_NULLPTR,sipName_headerData);

    if (!sipMeth)
        return  ::QStandardItemModel::headerData(a0,a1,a2);

    extern  ::QVariant sipVH_QtGui_93(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, ::Qt::Orientation,int);

    return sipVH_QtGui_93(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQStandardItemModel::setHeaderData(int a0, ::Qt::Orientation a1,const  ::QVariant& a2,int a3)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[16],sipPySelf,SIP_NULLPTR,sipName_setHeaderData);

    if (!sipMeth)
        return  ::QStandardItemModel::setHeaderData(a0,a1,a2,a3);

    extern bool sipVH_QtGui_92(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, ::Qt::Orientation,const  ::QVariant&,int);

    return sipVH_QtGui_92(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

QMap<int, ::QVariant> sipQStandardItemModel::itemData(const  ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[17]),sipPySelf,SIP_NULLPTR,sipName_itemData);

    if (!sipMeth)
        return  ::QStandardItemModel::itemData(a0);

    extern QMap<int, ::QVariant> sipVH_QtGui_91(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QModelIndex&);

    return sipVH_QtGui_91(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQStandardItemModel::setItemData(const  ::QModelIndex& a0,const QMap<int, ::QVariant>& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[18],sipPySelf,SIP_NULLPTR,sipName_setItemData);

    if (!sipMeth)
        return  ::QStandardItemModel::setItemData(a0,a1);

    extern bool sipVH_QtGui_90(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QModelIndex&,const QMap<int, ::QVariant>&);

    return sipVH_QtGui_90(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

 ::QStringList sipQStandardItemModel::mimeTypes() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[19]),sipPySelf,SIP_NULLPTR,sipName_mimeTypes);

    if (!sipMeth)
        return  ::QStandardItemModel::mimeTypes();

    extern  ::QStringList sipVH_QtGui_89(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_89(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QMimeData* sipQStandardItemModel::mimeData(const  ::QModelIndexList& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[20]),sipPySelf,SIP_NULLPTR,sipName_mimeData);

    if (!sipMeth)
        return  ::QStandardItemModel::mimeData(a0);

    extern  ::QMimeData* sipVH_QtGui_88(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QModelIndexList&);

    return sipVH_QtGui_88(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQStandardItemModel::dropMimeData(const  ::QMimeData*a0, ::Qt::DropAction a1,int a2,int a3,const  ::QModelIndex& a4)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[21],sipPySelf,SIP_NULLPTR,sipName_dropMimeData);

    if (!sipMeth)
        return  ::QStandardItemModel::dropMimeData(a0,a1,a2,a3,a4);

    extern bool sipVH_QtGui_77(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMimeData*, ::Qt::DropAction,int,int,const  ::QModelIndex&);

    return sipVH_QtGui_77(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

 ::Qt::DropActions sipQStandardItemModel::supportedDropActions() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[22]),sipPySelf,SIP_NULLPTR,sipName_supportedDropActions);

    if (!sipMeth)
        return  ::QStandardItemModel::supportedDropActions();

    extern  ::Qt::DropActions sipVH_QtGui_79(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_79(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQStandardItemModel::insertRows(int a0,int a1,const  ::QModelIndex& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[23],sipPySelf,SIP_NULLPTR,sipName_insertRows);

    if (!sipMeth)
        return  ::QStandardItemModel::insertRows(a0,a1,a2);

    extern bool sipVH_QtGui_87(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int,int,const  ::QModelIndex&);

    return sipVH_QtGui_87(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQStandardItemModel::insertColumns(int a0,int a1,const  ::QModelIndex& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[24],sipPySelf,SIP_NULLPTR,sipName_insertColumns);

    if (!sipMeth)
        return  ::QStandardItemModel::insertColumns(a0,a1,a2);

    extern bool sipVH_QtGui_87(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int,int,const  ::QModelIndex&);

    return sipVH_QtGui_87(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQStandardItemModel::removeRows(int a0,int a1,const  ::QModelIndex& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[25],sipPySelf,SIP_NULLPTR,sipName_removeRows);

    if (!sipMeth)
        return  ::QStandardItemModel::removeRows(a0,a1,a2);

    extern bool sipVH_QtGui_87(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int,int,const  ::QModelIndex&);

    return sipVH_QtGui_87(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQStandardItemModel::removeColumns(int a0,int a1,const  ::QModelIndex& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[26],sipPySelf,SIP_NULLPTR,sipName_removeColumns);

    if (!sipMeth)
        return  ::QStandardItemModel::removeColumns(a0,a1,a2);

    extern bool sipVH_QtGui_87(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int,int,const  ::QModelIndex&);

    return sipVH_QtGui_87(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQStandardItemModel::fetchMore(const  ::QModelIndex& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[27],sipPySelf,SIP_NULLPTR,sipName_fetchMore);

    if (!sipMeth)
    {
         ::QStandardItemModel::fetchMore(a0);
        return;
    }

    extern void sipVH_QtGui_86(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QModelIndex&);

    sipVH_QtGui_86(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQStandardItemModel::canFetchMore(const  ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[28]),sipPySelf,SIP_NULLPTR,sipName_canFetchMore);

    if (!sipMeth)
        return  ::QStandardItemModel::canFetchMore(a0);

    extern bool sipVH_QtGui_85(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QModelIndex&);

    return sipVH_QtGui_85(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::Qt::ItemFlags sipQStandardItemModel::flags(const  ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[29]),sipPySelf,SIP_NULLPTR,sipName_flags);

    if (!sipMeth)
        return  ::QStandardItemModel::flags(a0);

    extern  ::Qt::ItemFlags sipVH_QtGui_84(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QModelIndex&);

    return sipVH_QtGui_84(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStandardItemModel::sort(int a0, ::Qt::SortOrder a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[30],sipPySelf,SIP_NULLPTR,sipName_sort);

    if (!sipMeth)
    {
         ::QStandardItemModel::sort(a0,a1);
        return;
    }

    extern void sipVH_QtGui_83(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, ::Qt::SortOrder);

    sipVH_QtGui_83(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

 ::QModelIndex sipQStandardItemModel::buddy(const  ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[31]),sipPySelf,SIP_NULLPTR,sipName_buddy);

    if (!sipMeth)
        return  ::QStandardItemModel::buddy(a0);

    extern  ::QModelIndex sipVH_QtGui_82(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QModelIndex&);

    return sipVH_QtGui_82(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::QModelIndexList sipQStandardItemModel::match(const  ::QModelIndex& a0,int a1,const  ::QVariant& a2,int a3, ::Qt::MatchFlags a4) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[32]),sipPySelf,SIP_NULLPTR,sipName_match);

    if (!sipMeth)
        return  ::QStandardItemModel::match(a0,a1,a2,a3,a4);

    extern  ::QModelIndexList sipVH_QtGui_81(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QModelIndex&,int,const  ::QVariant&,int, ::Qt::MatchFlags);

    return sipVH_QtGui_81(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

 ::QSize sipQStandardItemModel::span(const  ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[33]),sipPySelf,SIP_NULLPTR,sipName_span);

    if (!sipMeth)
        return  ::QStandardItemModel::span(a0);

    extern  ::QSize sipVH_QtGui_80(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QModelIndex&);

    return sipVH_QtGui_80(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQStandardItemModel::submit()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[34],sipPySelf,SIP_NULLPTR,sipName_submit);

    if (!sipMeth)
        return  ::QStandardItemModel::submit();

    extern bool sipVH_QtGui_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_28(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQStandardItemModel::revert()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[35],sipPySelf,SIP_NULLPTR,sipName_revert);

    if (!sipMeth)
    {
         ::QStandardItemModel::revert();
        return;
    }

    extern void sipVH_QtGui_39(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtGui_39(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::Qt::DropActions sipQStandardItemModel::supportedDragActions() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[36]),sipPySelf,SIP_NULLPTR,sipName_supportedDragActions);

    if (!sipMeth)
        return  ::QStandardItemModel::supportedDragActions();

    extern  ::Qt::DropActions sipVH_QtGui_79(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_79(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

QHash<int, ::QByteArray> sipQStandardItemModel::roleNames() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[37]),sipPySelf,SIP_NULLPTR,sipName_roleNames);

    if (!sipMeth)
        return  ::QStandardItemModel::roleNames();

    extern QHash<int, ::QByteArray> sipVH_QtGui_78(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_78(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQStandardItemModel::canDropMimeData(const  ::QMimeData*a0, ::Qt::DropAction a1,int a2,int a3,const  ::QModelIndex& a4) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[38]),sipPySelf,SIP_NULLPTR,sipName_canDropMimeData);

    if (!sipMeth)
        return  ::QStandardItemModel::canDropMimeData(a0,a1,a2,a3,a4);

    extern bool sipVH_QtGui_77(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMimeData*, ::Qt::DropAction,int,int,const  ::QModelIndex&);

    return sipVH_QtGui_77(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

bool sipQStandardItemModel::moveRows(const  ::QModelIndex& a0,int a1,int a2,const  ::QModelIndex& a3,int a4)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[39],sipPySelf,SIP_NULLPTR,sipName_moveRows);

    if (!sipMeth)
        return  ::QStandardItemModel::moveRows(a0,a1,a2,a3,a4);

    extern bool sipVH_QtGui_76(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QModelIndex&,int,int,const  ::QModelIndex&,int);

    return sipVH_QtGui_76(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

bool sipQStandardItemModel::moveColumns(const  ::QModelIndex& a0,int a1,int a2,const  ::QModelIndex& a3,int a4)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[40],sipPySelf,SIP_NULLPTR,sipName_moveColumns);

    if (!sipMeth)
        return  ::QStandardItemModel::moveColumns(a0,a1,a2,a3,a4);

    extern bool sipVH_QtGui_76(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QModelIndex&,int,int,const  ::QModelIndex&,int);

    return sipVH_QtGui_76(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}


PyDoc_STRVAR(doc_QStandardItemModel_index, "index(self, int, int, parent: QModelIndex = QModelIndex()) -> QModelIndex");

extern "C" {static PyObject *meth_QStandardItemModel_index(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_index(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        int a1;
        const  ::QModelIndex& a2def = QModelIndex();
        const  ::QModelIndex* a2 = &a2def;
        const  ::QStandardItemModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|J9", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
             ::QModelIndex*sipRes;

            sipRes = new  ::QModelIndex((sipSelfWasArg ? sipCpp-> ::QStandardItemModel::index(a0,a1,*a2) : sipCpp->index(a0,a1,*a2)));

            return sipConvertFromNewType(sipRes,sipType_QModelIndex,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_index, doc_QStandardItemModel_index);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_parent, "parent(self, QModelIndex) -> QModelIndex\n"
"parent(self) -> QObject");

extern "C" {static PyObject *meth_QStandardItemModel_parent(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_parent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QModelIndex* a0;
        const  ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QModelIndex, &a0))
        {
             ::QModelIndex*sipRes;

            sipRes = new  ::QModelIndex((sipSelfWasArg ? sipCpp-> ::QStandardItemModel::parent(*a0) : sipCpp->parent(*a0)));

            return sipConvertFromNewType(sipRes,sipType_QModelIndex,SIP_NULLPTR);
        }
    }

    {
        const  ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItemModel, &sipCpp))
        {
             ::QObject*sipRes;

            sipRes = sipCpp->parent();

            return sipConvertFromType(sipRes,sipType_QObject,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_parent, doc_QStandardItemModel_parent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_rowCount, "rowCount(self, parent: QModelIndex = QModelIndex()) -> int");

extern "C" {static PyObject *meth_QStandardItemModel_rowCount(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_rowCount(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QModelIndex& a0def = QModelIndex();
        const  ::QModelIndex* a0 = &a0def;
        const  ::QStandardItemModel *sipCpp;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QStandardItemModel::rowCount(*a0) : sipCpp->rowCount(*a0));

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_rowCount, doc_QStandardItemModel_rowCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_columnCount, "columnCount(self, parent: QModelIndex = QModelIndex()) -> int");

extern "C" {static PyObject *meth_QStandardItemModel_columnCount(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_columnCount(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QModelIndex& a0def = QModelIndex();
        const  ::QModelIndex* a0 = &a0def;
        const  ::QStandardItemModel *sipCpp;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QStandardItemModel::columnCount(*a0) : sipCpp->columnCount(*a0));

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_columnCount, doc_QStandardItemModel_columnCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_hasChildren, "hasChildren(self, parent: QModelIndex = QModelIndex()) -> bool");

extern "C" {static PyObject *meth_QStandardItemModel_hasChildren(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_hasChildren(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QModelIndex& a0def = QModelIndex();
        const  ::QModelIndex* a0 = &a0def;
        const  ::QStandardItemModel *sipCpp;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QStandardItemModel::hasChildren(*a0) : sipCpp->hasChildren(*a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_hasChildren, doc_QStandardItemModel_hasChildren);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_data, "data(self, QModelIndex, role: int = Qt.DisplayRole) -> Any");

extern "C" {static PyObject *meth_QStandardItemModel_data(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_data(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QModelIndex* a0;
        int a1 = Qt::DisplayRole;
        const  ::QStandardItemModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|i", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QModelIndex, &a0, &a1))
        {
             ::QVariant*sipRes;

            sipRes = new  ::QVariant((sipSelfWasArg ? sipCpp-> ::QStandardItemModel::data(*a0,a1) : sipCpp->data(*a0,a1)));

            return sipConvertFromNewType(sipRes,sipType_QVariant,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_data, doc_QStandardItemModel_data);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_setData, "setData(self, QModelIndex, Any, role: int = Qt.EditRole) -> bool");

extern "C" {static PyObject *meth_QStandardItemModel_setData(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_setData(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QModelIndex* a0;
        const  ::QVariant* a1;
        int a1State = 0;
        int a2 = Qt::EditRole;
         ::QStandardItemModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9J1|i", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QModelIndex, &a0, sipType_QVariant, &a1, &a1State, &a2))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QStandardItemModel::setData(*a0,*a1,a2) : sipCpp->setData(*a0,*a1,a2));
            sipReleaseType(const_cast< ::QVariant *>(a1),sipType_QVariant,a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_setData, doc_QStandardItemModel_setData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_headerData, "headerData(self, int, Qt.Orientation, role: int = Qt.DisplayRole) -> Any");

extern "C" {static PyObject *meth_QStandardItemModel_headerData(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_headerData(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
         ::Qt::Orientation a1;
        int a2 = Qt::DisplayRole;
        const  ::QStandardItemModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BiE|i", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, sipType_Qt_Orientation, &a1, &a2))
        {
             ::QVariant*sipRes;

            sipRes = new  ::QVariant((sipSelfWasArg ? sipCpp-> ::QStandardItemModel::headerData(a0,a1,a2) : sipCpp->headerData(a0,a1,a2)));

            return sipConvertFromNewType(sipRes,sipType_QVariant,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_headerData, doc_QStandardItemModel_headerData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_setHeaderData, "setHeaderData(self, int, Qt.Orientation, Any, role: int = Qt.EditRole) -> bool");

extern "C" {static PyObject *meth_QStandardItemModel_setHeaderData(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_setHeaderData(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
         ::Qt::Orientation a1;
        const  ::QVariant* a2;
        int a2State = 0;
        int a3 = Qt::EditRole;
         ::QStandardItemModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BiEJ1|i", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, sipType_Qt_Orientation, &a1, sipType_QVariant, &a2, &a2State, &a3))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QStandardItemModel::setHeaderData(a0,a1,*a2,a3) : sipCpp->setHeaderData(a0,a1,*a2,a3));
            sipReleaseType(const_cast< ::QVariant *>(a2),sipType_QVariant,a2State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_setHeaderData, doc_QStandardItemModel_setHeaderData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_insertRows, "insertRows(self, int, int, parent: QModelIndex = QModelIndex()) -> bool");

extern "C" {static PyObject *meth_QStandardItemModel_insertRows(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_insertRows(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        int a1;
        const  ::QModelIndex& a2def = QModelIndex();
        const  ::QModelIndex* a2 = &a2def;
         ::QStandardItemModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|J9", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QStandardItemModel::insertRows(a0,a1,*a2) : sipCpp->insertRows(a0,a1,*a2));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_insertRows, doc_QStandardItemModel_insertRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_insertColumns, "insertColumns(self, int, int, parent: QModelIndex = QModelIndex()) -> bool");

extern "C" {static PyObject *meth_QStandardItemModel_insertColumns(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_insertColumns(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        int a1;
        const  ::QModelIndex& a2def = QModelIndex();
        const  ::QModelIndex* a2 = &a2def;
         ::QStandardItemModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|J9", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QStandardItemModel::insertColumns(a0,a1,*a2) : sipCpp->insertColumns(a0,a1,*a2));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_insertColumns, doc_QStandardItemModel_insertColumns);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_removeRows, "removeRows(self, int, int, parent: QModelIndex = QModelIndex()) -> bool");

extern "C" {static PyObject *meth_QStandardItemModel_removeRows(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_removeRows(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        int a1;
        const  ::QModelIndex& a2def = QModelIndex();
        const  ::QModelIndex* a2 = &a2def;
         ::QStandardItemModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|J9", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QStandardItemModel::removeRows(a0,a1,*a2) : sipCpp->removeRows(a0,a1,*a2));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_removeRows, doc_QStandardItemModel_removeRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_removeColumns, "removeColumns(self, int, int, parent: QModelIndex = QModelIndex()) -> bool");

extern "C" {static PyObject *meth_QStandardItemModel_removeColumns(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_removeColumns(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        int a1;
        const  ::QModelIndex& a2def = QModelIndex();
        const  ::QModelIndex* a2 = &a2def;
         ::QStandardItemModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|J9", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QStandardItemModel::removeColumns(a0,a1,*a2) : sipCpp->removeColumns(a0,a1,*a2));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_removeColumns, doc_QStandardItemModel_removeColumns);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_flags, "flags(self, QModelIndex) -> Qt.ItemFlags");

extern "C" {static PyObject *meth_QStandardItemModel_flags(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_flags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QModelIndex* a0;
        const  ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QModelIndex, &a0))
        {
             ::Qt::ItemFlags*sipRes;

            sipRes = new  ::Qt::ItemFlags((sipSelfWasArg ? sipCpp-> ::QStandardItemModel::flags(*a0) : sipCpp->flags(*a0)));

            return sipConvertFromNewType(sipRes,sipType_Qt_ItemFlags,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_flags, doc_QStandardItemModel_flags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_clear, "clear(self)");

extern "C" {static PyObject *meth_QStandardItemModel_clear(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItemModel, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_clear, doc_QStandardItemModel_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_supportedDropActions, "supportedDropActions(self) -> Qt.DropActions");

extern "C" {static PyObject *meth_QStandardItemModel_supportedDropActions(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_supportedDropActions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItemModel, &sipCpp))
        {
             ::Qt::DropActions*sipRes;

            sipRes = new  ::Qt::DropActions((sipSelfWasArg ? sipCpp-> ::QStandardItemModel::supportedDropActions() : sipCpp->supportedDropActions()));

            return sipConvertFromNewType(sipRes,sipType_Qt_DropActions,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_supportedDropActions, doc_QStandardItemModel_supportedDropActions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_itemData, "itemData(self, QModelIndex) -> Dict[int, Any]");

extern "C" {static PyObject *meth_QStandardItemModel_itemData(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_itemData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QModelIndex* a0;
        const  ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            QMap<int, ::QVariant>*sipRes;

            sipRes = new QMap<int, ::QVariant>((sipSelfWasArg ? sipCpp-> ::QStandardItemModel::itemData(*a0) : sipCpp->itemData(*a0)));

            return sipConvertFromNewType(sipRes,sipType_QMap_1800_0100QVariant,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_itemData, doc_QStandardItemModel_itemData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_setItemData, "setItemData(self, QModelIndex, Dict[int, Any]) -> bool");

extern "C" {static PyObject *meth_QStandardItemModel_setItemData(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_setItemData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QModelIndex* a0;
        const QMap<int, ::QVariant>* a1;
        int a1State = 0;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QModelIndex, &a0, sipType_QMap_1800_0100QVariant,&a1, &a1State))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QStandardItemModel::setItemData(*a0,*a1) : sipCpp->setItemData(*a0,*a1));
            sipReleaseType(const_cast<QMap<int, ::QVariant> *>(a1),sipType_QMap_1800_0100QVariant,a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_setItemData, doc_QStandardItemModel_setItemData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_sort, "sort(self, int, order: Qt.SortOrder = Qt.AscendingOrder)");

extern "C" {static PyObject *meth_QStandardItemModel_sort(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_sort(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
         ::Qt::SortOrder a1 = Qt::AscendingOrder;
         ::QStandardItemModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_order,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|E", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, sipType_Qt_SortOrder, &a1))
        {
            (sipSelfWasArg ? sipCpp-> ::QStandardItemModel::sort(a0,a1) : sipCpp->sort(a0,a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_sort, doc_QStandardItemModel_sort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_itemFromIndex, "itemFromIndex(self, QModelIndex) -> QStandardItem");

extern "C" {static PyObject *meth_QStandardItemModel_itemFromIndex(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_itemFromIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QModelIndex* a0;
        const  ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QModelIndex, &a0))
        {
             ::QStandardItem*sipRes;

            sipRes = sipCpp->itemFromIndex(*a0);

            return sipConvertFromType(sipRes,sipType_QStandardItem,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_itemFromIndex, doc_QStandardItemModel_itemFromIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_indexFromItem, "indexFromItem(self, QStandardItem) -> QModelIndex");

extern "C" {static PyObject *meth_QStandardItemModel_indexFromItem(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_indexFromItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStandardItem* a0;
        const  ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QStandardItem, &a0))
        {
             ::QModelIndex*sipRes;

            sipRes = new  ::QModelIndex(sipCpp->indexFromItem(a0));

            return sipConvertFromNewType(sipRes,sipType_QModelIndex,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_indexFromItem, doc_QStandardItemModel_indexFromItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_item, "item(self, int, column: int = 0) -> QStandardItem");

extern "C" {static PyObject *meth_QStandardItemModel_item(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_item(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1 = 0;
        const  ::QStandardItemModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_column,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|i", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, &a1))
        {
             ::QStandardItem*sipRes;

            sipRes = sipCpp->item(a0,a1);

            return sipConvertFromType(sipRes,sipType_QStandardItem,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_item, doc_QStandardItemModel_item);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_setItem, "setItem(self, int, int, QStandardItem)\n"
"setItem(self, int, QStandardItem)");

extern "C" {static PyObject *meth_QStandardItemModel_setItem(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_setItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
         ::QStandardItem* a2;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiJ:", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, &a1, sipType_QStandardItem, &a2))
        {
            sipCpp->setItem(a0,a1,a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
         ::QStandardItem* a1;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ:", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, sipType_QStandardItem, &a1))
        {
            sipCpp->setItem(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_setItem, doc_QStandardItemModel_setItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_invisibleRootItem, "invisibleRootItem(self) -> QStandardItem");

extern "C" {static PyObject *meth_QStandardItemModel_invisibleRootItem(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_invisibleRootItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItemModel, &sipCpp))
        {
             ::QStandardItem*sipRes;

            sipRes = sipCpp->invisibleRootItem();

            return sipConvertFromType(sipRes,sipType_QStandardItem,sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_invisibleRootItem, doc_QStandardItemModel_invisibleRootItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_horizontalHeaderItem, "horizontalHeaderItem(self, int) -> QStandardItem");

extern "C" {static PyObject *meth_QStandardItemModel_horizontalHeaderItem(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_horizontalHeaderItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const  ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0))
        {
             ::QStandardItem*sipRes;

            sipRes = sipCpp->horizontalHeaderItem(a0);

            return sipConvertFromType(sipRes,sipType_QStandardItem,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_horizontalHeaderItem, doc_QStandardItemModel_horizontalHeaderItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_setHorizontalHeaderItem, "setHorizontalHeaderItem(self, int, QStandardItem)");

extern "C" {static PyObject *meth_QStandardItemModel_setHorizontalHeaderItem(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_setHorizontalHeaderItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QStandardItem* a1;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ:", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, sipType_QStandardItem, &a1))
        {
            sipCpp->setHorizontalHeaderItem(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_setHorizontalHeaderItem, doc_QStandardItemModel_setHorizontalHeaderItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_verticalHeaderItem, "verticalHeaderItem(self, int) -> QStandardItem");

extern "C" {static PyObject *meth_QStandardItemModel_verticalHeaderItem(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_verticalHeaderItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const  ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0))
        {
             ::QStandardItem*sipRes;

            sipRes = sipCpp->verticalHeaderItem(a0);

            return sipConvertFromType(sipRes,sipType_QStandardItem,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_verticalHeaderItem, doc_QStandardItemModel_verticalHeaderItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_setVerticalHeaderItem, "setVerticalHeaderItem(self, int, QStandardItem)");

extern "C" {static PyObject *meth_QStandardItemModel_setVerticalHeaderItem(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_setVerticalHeaderItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QStandardItem* a1;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ:", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, sipType_QStandardItem, &a1))
        {
            sipCpp->setVerticalHeaderItem(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_setVerticalHeaderItem, doc_QStandardItemModel_setVerticalHeaderItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_setHorizontalHeaderLabels, "setHorizontalHeaderLabels(self, Iterable[str])");

extern "C" {static PyObject *meth_QStandardItemModel_setHorizontalHeaderLabels(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_setHorizontalHeaderLabels(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStringList* a0;
        int a0State = 0;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QStringList,&a0, &a0State))
        {
            sipCpp->setHorizontalHeaderLabels(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0),sipType_QStringList,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_setHorizontalHeaderLabels, doc_QStandardItemModel_setHorizontalHeaderLabels);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_setVerticalHeaderLabels, "setVerticalHeaderLabels(self, Iterable[str])");

extern "C" {static PyObject *meth_QStandardItemModel_setVerticalHeaderLabels(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_setVerticalHeaderLabels(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStringList* a0;
        int a0State = 0;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QStringList,&a0, &a0State))
        {
            sipCpp->setVerticalHeaderLabels(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0),sipType_QStringList,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_setVerticalHeaderLabels, doc_QStandardItemModel_setVerticalHeaderLabels);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_setRowCount, "setRowCount(self, int)");

extern "C" {static PyObject *meth_QStandardItemModel_setRowCount(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_setRowCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0))
        {
            sipCpp->setRowCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_setRowCount, doc_QStandardItemModel_setRowCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_setColumnCount, "setColumnCount(self, int)");

extern "C" {static PyObject *meth_QStandardItemModel_setColumnCount(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_setColumnCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0))
        {
            sipCpp->setColumnCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_setColumnCount, doc_QStandardItemModel_setColumnCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_appendRow, "appendRow(self, Iterable[QStandardItem])\n"
"appendRow(self, QStandardItem)");

extern "C" {static PyObject *meth_QStandardItemModel_appendRow(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_appendRow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QStandardItem*>* a0;
        int a0State = 0;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ3", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QList_0101QStandardItem,&a0, &a0State))
        {
            sipCpp->appendRow(*a0);
            sipReleaseType(const_cast<QList< ::QStandardItem*> *>(a0),sipType_QList_0101QStandardItem,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
         ::QStandardItem* a0;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QStandardItem, &a0))
        {
            sipCpp->appendRow(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_appendRow, doc_QStandardItemModel_appendRow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_appendColumn, "appendColumn(self, Iterable[QStandardItem])");

extern "C" {static PyObject *meth_QStandardItemModel_appendColumn(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_appendColumn(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QStandardItem*>* a0;
        int a0State = 0;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ3", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QList_0101QStandardItem,&a0, &a0State))
        {
            sipCpp->appendColumn(*a0);
            sipReleaseType(const_cast<QList< ::QStandardItem*> *>(a0),sipType_QList_0101QStandardItem,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_appendColumn, doc_QStandardItemModel_appendColumn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_insertRow, "insertRow(self, int, Iterable[QStandardItem])\n"
"insertRow(self, int, QStandardItem)\n"
"insertRow(self, int, parent: QModelIndex = QModelIndex()) -> bool");

extern "C" {static PyObject *meth_QStandardItemModel_insertRow(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_insertRow(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const QList< ::QStandardItem*>* a1;
        int a1State = 0;
         ::QStandardItemModel *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BiJ3", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, sipType_QList_0101QStandardItem,&a1, &a1State))
        {
            sipCpp->insertRow(a0,*a1);
            sipReleaseType(const_cast<QList< ::QStandardItem*> *>(a1),sipType_QList_0101QStandardItem,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
         ::QStandardItem* a1;
         ::QStandardItemModel *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BiJ:", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, sipType_QStandardItem, &a1))
        {
            sipCpp->insertRow(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        const  ::QModelIndex& a1def = QModelIndex();
        const  ::QModelIndex* a1 = &a1def;
         ::QStandardItemModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|J9", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, sipType_QModelIndex, &a1))
        {
            bool sipRes;

            sipRes = sipCpp->insertRow(a0,*a1);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_insertRow, doc_QStandardItemModel_insertRow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_insertColumn, "insertColumn(self, int, Iterable[QStandardItem])\n"
"insertColumn(self, int, parent: QModelIndex = QModelIndex()) -> bool");

extern "C" {static PyObject *meth_QStandardItemModel_insertColumn(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_insertColumn(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const QList< ::QStandardItem*>* a1;
        int a1State = 0;
         ::QStandardItemModel *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BiJ3", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, sipType_QList_0101QStandardItem,&a1, &a1State))
        {
            sipCpp->insertColumn(a0,*a1);
            sipReleaseType(const_cast<QList< ::QStandardItem*> *>(a1),sipType_QList_0101QStandardItem,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        const  ::QModelIndex& a1def = QModelIndex();
        const  ::QModelIndex* a1 = &a1def;
         ::QStandardItemModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|J9", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, sipType_QModelIndex, &a1))
        {
            bool sipRes;

            sipRes = sipCpp->insertColumn(a0,*a1);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_insertColumn, doc_QStandardItemModel_insertColumn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_takeItem, "takeItem(self, int, column: int = 0) -> QStandardItem");

extern "C" {static PyObject *meth_QStandardItemModel_takeItem(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_takeItem(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1 = 0;
         ::QStandardItemModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_column,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|i", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, &a1))
        {
             ::QStandardItem*sipRes;

            sipRes = sipCpp->takeItem(a0,a1);

            return sipConvertFromType(sipRes,sipType_QStandardItem,Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_takeItem, doc_QStandardItemModel_takeItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_takeRow, "takeRow(self, int) -> List[QStandardItem]");

extern "C" {static PyObject *meth_QStandardItemModel_takeRow(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_takeRow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0))
        {
            QList< ::QStandardItem*>*sipRes;

            sipRes = new QList< ::QStandardItem*>(sipCpp->takeRow(a0));

            return sipConvertFromNewType(sipRes,sipType_QList_0101QStandardItem,Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_takeRow, doc_QStandardItemModel_takeRow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_takeColumn, "takeColumn(self, int) -> List[QStandardItem]");

extern "C" {static PyObject *meth_QStandardItemModel_takeColumn(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_takeColumn(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0))
        {
            QList< ::QStandardItem*>*sipRes;

            sipRes = new QList< ::QStandardItem*>(sipCpp->takeColumn(a0));

            return sipConvertFromNewType(sipRes,sipType_QList_0101QStandardItem,Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_takeColumn, doc_QStandardItemModel_takeColumn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_takeHorizontalHeaderItem, "takeHorizontalHeaderItem(self, int) -> QStandardItem");

extern "C" {static PyObject *meth_QStandardItemModel_takeHorizontalHeaderItem(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_takeHorizontalHeaderItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0))
        {
             ::QStandardItem*sipRes;

            sipRes = sipCpp->takeHorizontalHeaderItem(a0);

            return sipConvertFromType(sipRes,sipType_QStandardItem,Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_takeHorizontalHeaderItem, doc_QStandardItemModel_takeHorizontalHeaderItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_takeVerticalHeaderItem, "takeVerticalHeaderItem(self, int) -> QStandardItem");

extern "C" {static PyObject *meth_QStandardItemModel_takeVerticalHeaderItem(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_takeVerticalHeaderItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0))
        {
             ::QStandardItem*sipRes;

            sipRes = sipCpp->takeVerticalHeaderItem(a0);

            return sipConvertFromType(sipRes,sipType_QStandardItem,Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_takeVerticalHeaderItem, doc_QStandardItemModel_takeVerticalHeaderItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_itemPrototype, "itemPrototype(self) -> QStandardItem");

extern "C" {static PyObject *meth_QStandardItemModel_itemPrototype(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_itemPrototype(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItemModel, &sipCpp))
        {
            const  ::QStandardItem*sipRes;

            sipRes = sipCpp->itemPrototype();

            return sipConvertFromType(const_cast< ::QStandardItem *>(sipRes),sipType_QStandardItem,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_itemPrototype, doc_QStandardItemModel_itemPrototype);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_setItemPrototype, "setItemPrototype(self, QStandardItem)");

extern "C" {static PyObject *meth_QStandardItemModel_setItemPrototype(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_setItemPrototype(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStandardItem* a0;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QStandardItem, &a0))
        {
            sipCpp->setItemPrototype(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_setItemPrototype, doc_QStandardItemModel_setItemPrototype);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_findItems, "findItems(self, str, flags: Union[Qt.MatchFlags, Qt.MatchFlag] = Qt.MatchExactly, column: int = 0) -> List[QStandardItem]");

extern "C" {static PyObject *meth_QStandardItemModel_findItems(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_findItems(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::Qt::MatchFlags a1def = Qt::MatchExactly;
         ::Qt::MatchFlags* a1 = &a1def;
        int a1State = 0;
        int a2 = 0;
        const  ::QStandardItemModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_flags,
            sipName_column,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1i", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QString,&a0, &a0State, sipType_Qt_MatchFlags, &a1, &a1State, &a2))
        {
            QList< ::QStandardItem*>*sipRes;

            sipRes = new QList< ::QStandardItem*>(sipCpp->findItems(*a0,*a1,a2));
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(a1,sipType_Qt_MatchFlags,a1State);

            return sipConvertFromNewType(sipRes,sipType_QList_0101QStandardItem,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_findItems, doc_QStandardItemModel_findItems);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_sortRole, "sortRole(self) -> int");

extern "C" {static PyObject *meth_QStandardItemModel_sortRole(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_sortRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItemModel, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->sortRole();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_sortRole, doc_QStandardItemModel_sortRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_setSortRole, "setSortRole(self, int)");

extern "C" {static PyObject *meth_QStandardItemModel_setSortRole(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_setSortRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0))
        {
            sipCpp->setSortRole(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_setSortRole, doc_QStandardItemModel_setSortRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_mimeTypes, "mimeTypes(self) -> List[str]");

extern "C" {static PyObject *meth_QStandardItemModel_mimeTypes(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_mimeTypes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItemModel, &sipCpp))
        {
             ::QStringList*sipRes;

            sipRes = new  ::QStringList((sipSelfWasArg ? sipCpp-> ::QStandardItemModel::mimeTypes() : sipCpp->mimeTypes()));

            return sipConvertFromNewType(sipRes,sipType_QStringList,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_mimeTypes, doc_QStandardItemModel_mimeTypes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_mimeData, "mimeData(self, Iterable[QModelIndex]) -> QMimeData");

extern "C" {static PyObject *meth_QStandardItemModel_mimeData(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_mimeData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QModelIndexList* a0;
        int a0State = 0;
        const  ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QList_0100QModelIndex,&a0, &a0State))
        {
             ::QMimeData*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QStandardItemModel::mimeData(*a0) : sipCpp->mimeData(*a0));
            sipReleaseType(const_cast< ::QModelIndexList *>(a0),sipType_QList_0100QModelIndex,a0State);

            return sipConvertFromType(sipRes,sipType_QMimeData,Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_mimeData, doc_QStandardItemModel_mimeData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_dropMimeData, "dropMimeData(self, QMimeData, Qt.DropAction, int, int, QModelIndex) -> bool");

extern "C" {static PyObject *meth_QStandardItemModel_dropMimeData(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_dropMimeData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QMimeData* a0;
         ::Qt::DropAction a1;
        int a2;
        int a3;
        const  ::QModelIndex* a4;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8EiiJ9", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QMimeData, &a0, sipType_Qt_DropAction, &a1, &a2, &a3, sipType_QModelIndex, &a4))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QStandardItemModel::dropMimeData(a0,a1,a2,a3,*a4) : sipCpp->dropMimeData(a0,a1,a2,a3,*a4));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_dropMimeData, doc_QStandardItemModel_dropMimeData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_sibling, "sibling(self, int, int, QModelIndex) -> QModelIndex");

extern "C" {static PyObject *meth_QStandardItemModel_sibling(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_sibling(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        int a1;
        const  ::QModelIndex* a2;
        const  ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiJ9", &sipSelf, sipType_QStandardItemModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
             ::QModelIndex*sipRes;

            sipRes = new  ::QModelIndex((sipSelfWasArg ? sipCpp-> ::QStandardItemModel::sibling(a0,a1,*a2) : sipCpp->sibling(a0,a1,*a2)));

            return sipConvertFromNewType(sipRes,sipType_QModelIndex,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_sibling, doc_QStandardItemModel_sibling);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_setItemRoleNames, "setItemRoleNames(self, Dict[int, Union[QByteArray, bytes, bytearray]])");

extern "C" {static PyObject *meth_QStandardItemModel_setItemRoleNames(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_setItemRoleNames(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QHash<int, ::QByteArray>* a0;
        int a0State = 0;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QHash_1800_0100QByteArray,&a0, &a0State))
        {
            sipCpp->setItemRoleNames(*a0);
            sipReleaseType(const_cast<QHash<int, ::QByteArray> *>(a0),sipType_QHash_1800_0100QByteArray,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_setItemRoleNames, doc_QStandardItemModel_setItemRoleNames);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItemModel_clearItemData, "clearItemData(self, QModelIndex) -> bool");

extern "C" {static PyObject *meth_QStandardItemModel_clearItemData(PyObject *, PyObject *);}
static PyObject *meth_QStandardItemModel_clearItemData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QModelIndex* a0;
         ::QStandardItemModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QStandardItemModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->clearItemData(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItemModel, sipName_clearItemData, doc_QStandardItemModel_clearItemData);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QStandardItemModel(void *, const sipTypeDef *);}
static void *cast_QStandardItemModel(void *sipCppV, const sipTypeDef *targetType)
{
     ::QStandardItemModel *sipCpp = reinterpret_cast< ::QStandardItemModel *>(sipCppV);

    if (targetType == sipType_QAbstractItemModel)
        return static_cast< ::QAbstractItemModel *>(sipCpp);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QStandardItemModel(void *, int);}
static void release_QStandardItemModel(void *sipCppV, int)
{
     ::QStandardItemModel *sipCpp = reinterpret_cast< ::QStandardItemModel *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QStandardItemModel(Py_ssize_t);}
static void *array_QStandardItemModel(Py_ssize_t sipNrElem)
{
    return new  ::QStandardItemModel[sipNrElem];
}


extern "C" {static void dealloc_QStandardItemModel(sipSimpleWrapper *);}
static void dealloc_QStandardItemModel(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQStandardItemModel *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QStandardItemModel(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QStandardItemModel(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QStandardItemModel(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQStandardItemModel *sipCpp = SIP_NULLPTR;

    {
         ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQStandardItemModel(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        int a0;
        int a1;
         ::QObject* a2 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "ii|JH", &a0, &a1, sipType_QObject, &a2, sipOwner))
        {
            sipCpp = new sipQStandardItemModel(a0,a1,a2);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QStandardItemModel[] = {{0, 0, 1}};


static PyMethodDef methods_QStandardItemModel[] = {
    {SIP_MLNAME_CAST(sipName_appendColumn), meth_QStandardItemModel_appendColumn, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_appendColumn)},
    {SIP_MLNAME_CAST(sipName_appendRow), meth_QStandardItemModel_appendRow, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_appendRow)},
    {SIP_MLNAME_CAST(sipName_clear), meth_QStandardItemModel_clear, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_clear)},
    {SIP_MLNAME_CAST(sipName_clearItemData), meth_QStandardItemModel_clearItemData, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_clearItemData)},
    {SIP_MLNAME_CAST(sipName_columnCount), SIP_MLMETH_CAST(meth_QStandardItemModel_columnCount), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStandardItemModel_columnCount)},
    {SIP_MLNAME_CAST(sipName_data), SIP_MLMETH_CAST(meth_QStandardItemModel_data), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStandardItemModel_data)},
    {SIP_MLNAME_CAST(sipName_dropMimeData), meth_QStandardItemModel_dropMimeData, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_dropMimeData)},
    {SIP_MLNAME_CAST(sipName_findItems), SIP_MLMETH_CAST(meth_QStandardItemModel_findItems), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStandardItemModel_findItems)},
    {SIP_MLNAME_CAST(sipName_flags), meth_QStandardItemModel_flags, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_flags)},
    {SIP_MLNAME_CAST(sipName_hasChildren), SIP_MLMETH_CAST(meth_QStandardItemModel_hasChildren), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStandardItemModel_hasChildren)},
    {SIP_MLNAME_CAST(sipName_headerData), SIP_MLMETH_CAST(meth_QStandardItemModel_headerData), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStandardItemModel_headerData)},
    {SIP_MLNAME_CAST(sipName_horizontalHeaderItem), meth_QStandardItemModel_horizontalHeaderItem, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_horizontalHeaderItem)},
    {SIP_MLNAME_CAST(sipName_index), SIP_MLMETH_CAST(meth_QStandardItemModel_index), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStandardItemModel_index)},
    {SIP_MLNAME_CAST(sipName_indexFromItem), meth_QStandardItemModel_indexFromItem, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_indexFromItem)},
    {SIP_MLNAME_CAST(sipName_insertColumn), SIP_MLMETH_CAST(meth_QStandardItemModel_insertColumn), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStandardItemModel_insertColumn)},
    {SIP_MLNAME_CAST(sipName_insertColumns), SIP_MLMETH_CAST(meth_QStandardItemModel_insertColumns), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStandardItemModel_insertColumns)},
    {SIP_MLNAME_CAST(sipName_insertRow), SIP_MLMETH_CAST(meth_QStandardItemModel_insertRow), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStandardItemModel_insertRow)},
    {SIP_MLNAME_CAST(sipName_insertRows), SIP_MLMETH_CAST(meth_QStandardItemModel_insertRows), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStandardItemModel_insertRows)},
    {SIP_MLNAME_CAST(sipName_invisibleRootItem), meth_QStandardItemModel_invisibleRootItem, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_invisibleRootItem)},
    {SIP_MLNAME_CAST(sipName_item), SIP_MLMETH_CAST(meth_QStandardItemModel_item), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStandardItemModel_item)},
    {SIP_MLNAME_CAST(sipName_itemData), meth_QStandardItemModel_itemData, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_itemData)},
    {SIP_MLNAME_CAST(sipName_itemFromIndex), meth_QStandardItemModel_itemFromIndex, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_itemFromIndex)},
    {SIP_MLNAME_CAST(sipName_itemPrototype), meth_QStandardItemModel_itemPrototype, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_itemPrototype)},
    {SIP_MLNAME_CAST(sipName_mimeData), meth_QStandardItemModel_mimeData, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_mimeData)},
    {SIP_MLNAME_CAST(sipName_mimeTypes), meth_QStandardItemModel_mimeTypes, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_mimeTypes)},
    {SIP_MLNAME_CAST(sipName_parent), meth_QStandardItemModel_parent, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_parent)},
    {SIP_MLNAME_CAST(sipName_removeColumns), SIP_MLMETH_CAST(meth_QStandardItemModel_removeColumns), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStandardItemModel_removeColumns)},
    {SIP_MLNAME_CAST(sipName_removeRows), SIP_MLMETH_CAST(meth_QStandardItemModel_removeRows), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStandardItemModel_removeRows)},
    {SIP_MLNAME_CAST(sipName_rowCount), SIP_MLMETH_CAST(meth_QStandardItemModel_rowCount), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStandardItemModel_rowCount)},
    {SIP_MLNAME_CAST(sipName_setColumnCount), meth_QStandardItemModel_setColumnCount, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_setColumnCount)},
    {SIP_MLNAME_CAST(sipName_setData), SIP_MLMETH_CAST(meth_QStandardItemModel_setData), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStandardItemModel_setData)},
    {SIP_MLNAME_CAST(sipName_setHeaderData), SIP_MLMETH_CAST(meth_QStandardItemModel_setHeaderData), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStandardItemModel_setHeaderData)},
    {SIP_MLNAME_CAST(sipName_setHorizontalHeaderItem), meth_QStandardItemModel_setHorizontalHeaderItem, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_setHorizontalHeaderItem)},
    {SIP_MLNAME_CAST(sipName_setHorizontalHeaderLabels), meth_QStandardItemModel_setHorizontalHeaderLabels, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_setHorizontalHeaderLabels)},
    {SIP_MLNAME_CAST(sipName_setItem), meth_QStandardItemModel_setItem, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_setItem)},
    {SIP_MLNAME_CAST(sipName_setItemData), meth_QStandardItemModel_setItemData, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_setItemData)},
    {SIP_MLNAME_CAST(sipName_setItemPrototype), meth_QStandardItemModel_setItemPrototype, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_setItemPrototype)},
    {SIP_MLNAME_CAST(sipName_setItemRoleNames), meth_QStandardItemModel_setItemRoleNames, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_setItemRoleNames)},
    {SIP_MLNAME_CAST(sipName_setRowCount), meth_QStandardItemModel_setRowCount, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_setRowCount)},
    {SIP_MLNAME_CAST(sipName_setSortRole), meth_QStandardItemModel_setSortRole, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_setSortRole)},
    {SIP_MLNAME_CAST(sipName_setVerticalHeaderItem), meth_QStandardItemModel_setVerticalHeaderItem, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_setVerticalHeaderItem)},
    {SIP_MLNAME_CAST(sipName_setVerticalHeaderLabels), meth_QStandardItemModel_setVerticalHeaderLabels, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_setVerticalHeaderLabels)},
    {SIP_MLNAME_CAST(sipName_sibling), meth_QStandardItemModel_sibling, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_sibling)},
    {SIP_MLNAME_CAST(sipName_sort), SIP_MLMETH_CAST(meth_QStandardItemModel_sort), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStandardItemModel_sort)},
    {SIP_MLNAME_CAST(sipName_sortRole), meth_QStandardItemModel_sortRole, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_sortRole)},
    {SIP_MLNAME_CAST(sipName_supportedDropActions), meth_QStandardItemModel_supportedDropActions, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_supportedDropActions)},
    {SIP_MLNAME_CAST(sipName_takeColumn), meth_QStandardItemModel_takeColumn, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_takeColumn)},
    {SIP_MLNAME_CAST(sipName_takeHorizontalHeaderItem), meth_QStandardItemModel_takeHorizontalHeaderItem, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_takeHorizontalHeaderItem)},
    {SIP_MLNAME_CAST(sipName_takeItem), SIP_MLMETH_CAST(meth_QStandardItemModel_takeItem), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStandardItemModel_takeItem)},
    {SIP_MLNAME_CAST(sipName_takeRow), meth_QStandardItemModel_takeRow, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_takeRow)},
    {SIP_MLNAME_CAST(sipName_takeVerticalHeaderItem), meth_QStandardItemModel_takeVerticalHeaderItem, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_takeVerticalHeaderItem)},
    {SIP_MLNAME_CAST(sipName_verticalHeaderItem), meth_QStandardItemModel_verticalHeaderItem, METH_VARARGS, SIP_MLDOC_CAST(doc_QStandardItemModel_verticalHeaderItem)}
};

PyDoc_STRVAR(doc_QStandardItemModel, "\1QStandardItemModel(parent: QObject = None)\n"
"QStandardItemModel(int, int, parent: QObject = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QStandardItemModel[] = {
    {"itemChanged(QStandardItem*)", "\1itemChanged(self, QStandardItem)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QStandardItemModel = {
    & ::QStandardItemModel::staticMetaObject,
    0,
    signals_QStandardItemModel,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QStandardItemModel = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QStandardItemModel,
        {SIP_NULLPTR},
        &plugin_QStandardItemModel
    },
    {
        sipNameNr_QStandardItemModel,
        {0, 0, 1},
        52, methods_QStandardItemModel,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QStandardItemModel,
    -1,
    -1,
    supers_QStandardItemModel,
    SIP_NULLPTR,
    init_type_QStandardItemModel,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QStandardItemModel,
    SIP_NULLPTR,
    array_QStandardItemModel,
    SIP_NULLPTR,
    release_QStandardItemModel,
    cast_QStandardItemModel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
